==> open-xchange-global_6.10.0.0.orig.tar.gz: open-xchange-global-6.10.0.0/src/com/openexchange/exceptions/osgi/ComponentRegistration.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2006 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.exceptions.osgi;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTracker;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.exceptions.ComponentAlreadyRegisteredException;
import com.openexchange.exceptions.ComponentRegistry;
import com.openexchange.exceptions.Exceptions;
import com.openexchange.exceptions.StringComponent;
import com.openexchange.groupware.Component;

/**
 * @author Francisco Laguna <francisco.laguna@open-xchange.com>
 */
public class ComponentRegistration implements ServiceTrackerCustomizer {

    private static final Log LOG = LogFactory.getLog(ComponentRegistration.class);

    private final Component component;

    private final String applicationId;

    private final Exceptions<?> exceptions;

    private final BundleContext context;

    private ComponentRegistry registry;

    private final ServiceTracker serviceTracker;

    public ComponentRegistration(BundleContext context, String component, String applicationId, Exceptions<?> exceptions) {
        super();
        this.component = new StringComponent(component);
        this.applicationId = applicationId;
        this.exceptions = exceptions;
        this.context = context;
        serviceTracker = new ServiceTracker(context, ComponentRegistry.class.getName(), this);
        serviceTracker.open();
    }

    public ComponentRegistration(BundleContext context, Component component, String applicationId, Exceptions<?> exceptions) {
        super();
        this.component = component;
        this.applicationId = applicationId;
        this.exceptions = exceptions;
        this.context = context;
        serviceTracker = new ServiceTracker(context, ComponentRegistry.class.getName(), this);
        serviceTracker.open();
    }

    public void unregister() {
        serviceTracker.close();
    }

    public Object addingService(final ServiceReference serviceReference) {
        final Object addedService = context.getService(serviceReference);
        if (ComponentRegistry.class.isAssignableFrom(addedService.getClass())) {
            final ComponentRegistry registry = (ComponentRegistry) addedService;
            try {
                registry.registerComponent(component, applicationId, exceptions);
            } catch (final ComponentAlreadyRegisteredException e) {
                LOG.fatal(applicationId + " could not register component for excetpions: " + e.getMessage(), e);
            }
            this.registry = registry;
        }
        return addedService;
    }

    public void modifiedService(final ServiceReference serviceReference, final Object o) {
        // Nothing to do.
    }

    public void removedService(final ServiceReference serviceReference, final Object o) {
        registry.deregisterComponent(component);
        registry = null;
        context.ungetService(serviceReference);
    }
}

==> open-xchange-global_6.18.0.0.orig.tar.gz: open-xchange-global-6.18.0.0/src/com/openexchange/exceptions/osgi/ComponentRegistration.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.exceptions.osgi;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTracker;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.exceptions.ComponentAlreadyRegisteredException;
import com.openexchange.exceptions.ComponentRegistry;
import com.openexchange.exceptions.Exceptions;
import com.openexchange.exceptions.StringComponent;
import com.openexchange.groupware.Component;

/**
 * @author Francisco Laguna <francisco.laguna@open-xchange.com>
 */
public class ComponentRegistration implements ServiceTrackerCustomizer {

    private static final Log LOG = LogFactory.getLog(ComponentRegistration.class);

    private final Component component;

    private final String applicationId;

    private final Exceptions<?> exceptions;

    private final BundleContext context;

    private ComponentRegistry registry;

    private final ServiceTracker serviceTracker;

    public ComponentRegistration(final BundleContext context, final String component, final String applicationId, final Exceptions<?> exceptions) {
        super();
        this.component = new StringComponent(component);
        this.applicationId = applicationId;
        this.exceptions = exceptions;
        this.context = context;
        serviceTracker = new ServiceTracker(context, ComponentRegistry.class.getName(), this);
        serviceTracker.open();
    }

    public ComponentRegistration(final BundleContext context, final Component component, final String applicationId, final Exceptions<?> exceptions) {
        super();
        this.component = component;
        this.applicationId = applicationId;
        this.exceptions = exceptions;
        this.context = context;
        serviceTracker = new ServiceTracker(context, ComponentRegistry.class.getName(), this);
        serviceTracker.open();
    }

    public void unregister() {
        serviceTracker.close();
    }

    public Object addingService(final ServiceReference serviceReference) {
        final Object addedService = context.getService(serviceReference);
        if (ComponentRegistry.class.isAssignableFrom(addedService.getClass())) {
            final ComponentRegistry registry = (ComponentRegistry) addedService;
            try {
                registry.registerComponent(component, applicationId, exceptions);
            } catch (final ComponentAlreadyRegisteredException e) {
                LOG.fatal(applicationId + " could not register component for exceptions: " + e.getMessage(), e);
            }
            this.registry = registry;
        }
        return addedService;
    }

    public void modifiedService(final ServiceReference serviceReference, final Object o) {
        // Nothing to do.
    }

    public void removedService(final ServiceReference serviceReference, final Object o) {
        registry.deregisterComponent(component);
        registry = null;
        context.ungetService(serviceReference);
    }
}
